@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 #    OpaL Perl Modules
-#    Copyright (C) 2000,2007  Ola Lundqvist <ola@opalsys.net>
-#    $Id: action.pm 2527 2007-12-06 19:57:04Z ola $
+#    Copyright (C) 2000,2007-2008  Ola Lundqvist <ola@inguza.com>
+#
 #    For full COPYRIGHT notice see the COPYING document.
 #
 #    This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
 #
 #
 #    For more information take a look at the official homepage at:
-#      http://opalsys.net/software/opalmod
+#      http://inguza.com/software/opalmod
 #    or contact the author at:
-#      ola@opalsys.net
+#      ola@inguza.com
 #
 
 package OpaL::action;
@@ -84,7 +84,7 @@ my $errorHandler;
 # Name:		setErrorHandler
 # Description:	Sets the error handler function.
 # Arguments:	$function (no arguments).
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2002-01-22
 ###############################################################################
 sub setErrorHandler (&) {
@@ -96,7 +96,7 @@ sub setErrorHandler (&) {
 # Description:	Sets the debug level to something.
 # Arguments:	$level (1 to 5)
 # Changes:	The localy scooped $debuglvl
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-05-01
 ###############################################################################
 sub setDebugLevel ($) {
@@ -106,7 +106,7 @@ sub setDebugLevel ($) {
 ###############################################################################
 # Name:		getDebugLevel
 # Description:	returns the debug level.
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-07-06
 ###############################################################################
 sub getDebugLevel () {
@@ -118,7 +118,7 @@ sub getDebugLevel () {
 # Description:	Sets the quit level to something.
 # Arguments:	$level (1 to 5)
 # Changes:	The localy scooped $qlvl
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-05-01
 ###############################################################################
 sub setQuitLevel ($) {
@@ -128,7 +128,7 @@ sub setQuitLevel ($) {
 ###############################################################################
 # Name:		getQuitLevel
 # Description:	returns the quit level.
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-07-06
 ###############################################################################
 sub getQuitLevel () {
@@ -141,7 +141,7 @@ sub getQuitLevel () {
 #		to critical.
 # Arguments:	$level, $message, [exit ref function]
 # Uses:		exitlvl
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-05-01
 #		2000-05-04	Minor modifications.
 #		2000-06-27	Removed comment.
@@ -163,7 +163,7 @@ sub pdebug ($$;&) {
 # Name:		exitlvl
 # Description:	Exit the program if the level are to critical.
 # Arguments:	$level, [exit ref function]
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-05-01
 #		2000-06-27	Added argument definition ($).
 #		2002-01-22	Added exit ref function.
@@ -202,7 +202,7 @@ sub exitlvl ($;&) {
 # Description:	If eval is true then print out an error message.
 # Arguments:	$eval, $message, [$errlvl default 2], [exit ref function]
 # Uses:		pdebug
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-05-01
 #		2000-06-27	Added a $ to make sure that errlvl is ok.
 #				Added argument definition ($$:$).
@@ -227,7 +227,7 @@ sub action ($$;$&) {
 # Description:	If system(command) is erronious then call action.
 # Arguments:	$command, $message, [$errorlevel default 2], [$quiet]
 # Uses:		pdebug, action
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-05-01
 #		2000-05-19	Fixed quietcmd?
 #		2000-06-27	Added a $ to make sure that errlvl is ok.
@@ -413,7 +413,7 @@ The last parameter tells how quiet the executing command should be:
 
 =head1 AUTHOR
 
-Ola Lundqvist <ola@opalsys.net>
+Ola Lundqvist <ola@inguza.com>
 
 =head1 SEE ALSO
 
